@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * gcu/application.cc 
  *
- * Copyright (C) 2005-2007 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2005-2008 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -24,67 +24,68 @@
 
 #include "config.h"
 #include "application.h"
-#include <libgnomevfs/gnome-vfs-ops.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
+#include "cmd-context.h"
+#include "loader.h"
+#ifndef GOFFICE_HAS_GLOBAL_HEADER
+#   include <goffice/goffice.h>
+#   include <goffice/app/io-context.h>
+#   include <goffice/utils/go-file.h>
+#   include <gtk/gtk.h>
+#endif
+#include <gsf/gsf-input-gio.h>
+#include <gsf/gsf-output-gio.h>
 #include <glade/glade.h>
+#ifndef HAVE_GO_CONF_SYNC
 #include <gconf/gconf-client.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkspinbutton.h>
+#endif
 #include <glib/gi18n-lib.h>
 #include <sys/stat.h>
 #include <cmath>
 #include <cstdlib>
 #include <cstring>
+#include <clocale>
+#include <set>
 
 using namespace std;
 
 namespace gcu
 {
 
+#ifdef HAVE_GO_CONF_SYNC
+GOConfNode *Application::m_ConfDir = NULL;
+#endif
+
+static set<Application *> Apps;
+
 Application::Application (string name, string datadir, char const *help_name, char const *icon_name)
 {
+#ifdef HAVE_GO_CONF_SYNC
+	if (m_ConfDir == NULL) {
+		libgoffice_init ();
+		m_ConfDir = go_conf_get_node (NULL, GCU_CONF_DIR);
+	}
+#else
+	libgoffice_init ();
+#endif
+	Apps.insert (this);
 	static bool first_call = true;
 	Name = name;
 	char const *szlang = getenv ("LANG");
 	string lang = (szlang)? szlang: "C";
 	HelpName = help_name? help_name: Name;
-	HelpFilename = string ("file://") + datadir + string ("/gnome/help/") + HelpName + string ("/") + lang + string ("/") + HelpName + ".xml";
-	GnomeVFSURI *uri = gnome_vfs_uri_new (HelpFilename.c_str ());
-	bool exists = gnome_vfs_uri_exists (uri);
-	gnome_vfs_uri_unref (uri);
+	HelpFilename = string ("file://") + datadir + string ("/gnome/help/") + HelpName + string ("-"API_VERSION"/") + lang + string ("/") + HelpName + "-"API_VERSION".xml";
+	GFile *file = g_file_new_for_uri (HelpFilename.c_str ());
+	bool exists = g_file_query_exists (file, NULL);
+	g_object_unref (file);
 	if (!exists) {
-		HelpFilename = string ("file://") + datadir + string ("/gnome/help/") + HelpName + string ("/C/") + HelpName + ".xml";
+		HelpFilename = string ("file://") + datadir + string ("/gnome/help/") + HelpName + string ("-"API_VERSION"/C/") + HelpName + "-"API_VERSION".xml";
 	}
-	GConfClient* cli = gconf_client_get_default ();
-	if (cli) {
-		const char *value;
-		GConfEntry* entry = gconf_client_get_entry (cli, "/desktop/gnome/applications/help_viewer/exec", NULL, true, NULL);
-		if (entry) {
-			value = gconf_value_get_string (gconf_entry_get_value (entry));
-			if (value) {
-				HelpBrowser = value;
-				if (HelpBrowser.find ("nautilus") != string::npos)
-					HelpBrowser = "yelp";
-			}
-		} else
-			HelpBrowser = "yelp";
-		entry = gconf_client_get_entry (cli, "/desktop/gnome/applications/browser/exec", NULL, true, NULL);
-		if (entry) {
-			value = gconf_value_get_string (gconf_entry_get_value (entry));
-			if (value) WebBrowser = value;
-		}
-		entry = gconf_client_get_entry (cli, "/desktop/gnome/url-handlers/mailto/command", NULL, true, NULL);
-		if (entry) {
-			value = gconf_value_get_string (gconf_entry_get_value (entry));
-			if (value) {
-				MailAgent = value;
-				int i = MailAgent.find (" %s");
-				if (i > 0)
-					MailAgent.erase (i, MailAgent.size ());
-			}
-		}
-	}
-	CurDir = g_get_current_dir ();
+	HelpBrowser = "yelp"; // there is no more key for that
+	char *dir = g_get_current_dir ();
+	char *uri = g_filename_to_uri (dir, NULL, NULL);
+	g_free (dir);
+	CurDir = uri;
+	g_free (uri);
 	if (first_call) { // needed to create several applications in the same program instance
 		g_set_application_name (name.c_str ());
 		first_call = false;
@@ -94,7 +95,7 @@ Application::Application (string name, string datadir, char const *help_name, ch
 	m_ScreenResolution = (unsigned) rint (gdk_screen_get_width (screen) * 25.4 / gdk_screen_get_width_mm (screen));
 	m_ImageResolution = m_ScreenResolution;
 	m_ImageHeight = m_ImageWidth = 300;
-	m_RecentManager = gtk_recent_manager_new ();
+	m_RecentManager = gtk_recent_manager_get_default ();
 
 	// check supported pixbuf formats
 	GSList *formats = gdk_pixbuf_get_formats ();
@@ -115,7 +116,15 @@ Application::Application (string name, string datadir, char const *help_name, ch
 
 Application::~Application ()
 {
-	g_object_unref (m_RecentManager);
+	Apps.erase (this);
+	if (Apps.empty ()) {
+		ClearDialogs (); // needed to cleanly stop goffice
+#ifdef HAVE_GO_CONF_SYNC
+		go_conf_free_node (m_ConfDir);
+		m_ConfDir = NULL;
+#endif
+		libgoffice_shutdown ();
+	}
 }
 
 void Application::OnHelp (string tag)
@@ -136,10 +145,10 @@ bool Application::HasHelp ()
 {
 	if (!HelpBrowser.length () || !HelpFilename.length ())
 		return false;
-	GnomeVFSURI *uri = gnome_vfs_uri_new (HelpFilename.c_str ());
-	bool err = gnome_vfs_uri_exists (uri);
-	gnome_vfs_uri_unref (uri);
-	return err;	
+	GFile *file = g_file_new_for_uri (HelpFilename.c_str ());
+	bool exists = g_file_query_exists (file, NULL);
+	g_object_unref (file);
+	return exists;	
 }
 
 void Application::SetCurDir (char const* dir)
@@ -154,23 +163,17 @@ void Application::SetCurDir (string const &dir)
 
 void Application::OnMail (char const *MailAddress)
 {
-	if (!MailAgent.size ())
-		return;
-	char *argv[3] = {NULL, const_cast<char*> (MailAddress), NULL};
-	argv[0] = (char*) MailAgent.c_str();
-	g_spawn_async (NULL, argv, NULL, G_SPAWN_SEARCH_PATH,
-		NULL, NULL, NULL, NULL);
+	go_url_show (MailAddress);
 }
 
 void Application::ShowURI (string& uri)
 {
-	if (!WebBrowser.size ())
-		return;
-	char *argv[3] = {NULL, NULL, NULL};
-	argv[0] = (char*) WebBrowser.c_str();
-	argv[1] = (char*) uri.c_str ();
-	g_spawn_async (NULL, argv, NULL, G_SPAWN_SEARCH_PATH,
-		NULL, NULL, NULL, NULL);
+	go_url_show (uri.c_str ());
+}
+
+void Application::OnLiveAssistance ()
+{
+	go_url_show ("irc://irc.gimp.net/gchemutils");
 }
 
 static void on_res_changed (GtkSpinButton *btn, Application *app)
@@ -248,4 +251,56 @@ void Application::RemoveDocument (Document *Doc)
 		NoMoreDocsEvent ();
 }
 
+bool Application::Load (std::string const &uri, const gchar *mime_type, Document* Doc)
+{
+	Loader *l = Loader::GetLoader (mime_type);
+	if (!l)
+		return false;
+	string old_num_locale = setlocale (LC_NUMERIC, NULL);
+	setlocale (LC_NUMERIC, "C");
+	GError *error = NULL;
+	GsfInput *input = gsf_input_gio_new_for_uri (uri.c_str (), &error);
+	if (error) {
+		g_error_free (error);
+		return false;
+	}
+	IOContext *io = gnumeric_io_context_new (gcu_get_cmd_context ());
+	bool ret = l->Read (Doc, input, mime_type, io);
+	g_object_unref (input);
+	g_object_unref (io);
+	setlocale (LC_NUMERIC, old_num_locale.c_str ());
+	return ret;
+}
+
+bool Application::Save (std::string const &uri, const gchar *mime_type, Document* Doc)
+{
+	Loader *l = Loader::GetSaver (mime_type);
+	if (!l)
+		return false;
+	string old_num_locale = setlocale (LC_NUMERIC, NULL);
+	setlocale (LC_NUMERIC, "C");
+	GError *error = NULL;
+	GsfOutput *output = gsf_output_gio_new_for_uri (uri.c_str (), &error);
+	if (error) {
+		g_error_free (error);
+	}
+	IOContext*io  = gnumeric_io_context_new (gcu_get_cmd_context ());
+	bool ret = l->Write (Doc, output, mime_type, io);
+	g_object_unref (output);
+	g_object_unref (io);
+	setlocale (LC_NUMERIC, old_num_locale.c_str ());
+	return ret;
+}
+
+#ifdef HAVE_GO_CONF_SYNC
+GOConfNode *Application::GetConfDir ()
+{
+	if (m_ConfDir == NULL) {
+		libgoffice_init ();
+		m_ConfDir = go_conf_get_node (NULL, GCU_CONF_DIR);
+	}
+	return m_ConfDir;
+}
+#endif
+
 }	//	namespace gcu
