@@ -2,7 +2,7 @@
  * Gnome Chemisty Utils
  * chem-viewer.c 
  *
- * Copyright (C) 2005-2008
+ * Copyright (C) 2005-2008 Jean Bréfort <jean.brefort@normalesup.org>
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
  * published by the Free Software Foundation; either version 2 of the
@@ -31,8 +31,10 @@
 #include <gcp/view.h>
 #include <gcp/widgetdata.h>
 #include <goffice/goffice.h>
-#include <goffice/app/go-plugin.h>
-#include <goffice/app/go-plugin-loader-module.h>
+#ifndef GOFFICE_HAS_GLOBAL_HEADER
+#   include <goffice/app/go-plugin.h>
+#   include <goffice/app/go-plugin-loader-module.h>
+#endif
 #include <gdk/gdkx.h>
 #include <gtk/gtkmain.h>
 #include <gtk/gtkplug.h>
@@ -47,6 +49,10 @@
 #include <string>
 #include <cstring>
 
+#ifndef GO_TYPE_PLUGIN_LOADER_MODULE
+#   define GO_TYPE_PLUGIN_LOADER_MODULE GO_PLUGIN_LOADER_MODULE_TYPE
+#endif
+
 using namespace std;
 using namespace gcu;
 
@@ -172,10 +178,14 @@ void ChemComp::SetFilename (string& filename)
 		pData->GetObjectBounds (Doc, &r);
 		xmlFree (xml);
 	} else 	if (MimeType == "chemical/x-jcamp-dx") {
-		gtk_spectrum_viewer_set_uri (GTK_SPECTRUM_VIEWER (Viewer), filename.c_str ());
+		char *uri = g_filename_to_uri (filename.c_str (), NULL, NULL);
+		gtk_spectrum_viewer_set_uri (GTK_SPECTRUM_VIEWER (Viewer), uri);
+		g_free (uri);
 	} else {
+		char *uri = g_filename_to_uri (filename.c_str (), NULL, NULL);
 		gtk_chem3d_viewer_set_uri_with_mime_type (GTK_CHEM3D_VIEWER (Viewer),
-				filename.c_str (), MimeType.c_str ());
+				uri, MimeType.c_str ());
+		g_free (uri);
 		map<string, string>::iterator i, iend = Params.end ();
 		for (i = Params.begin (); i != iend; i++) {
 			if ((*i).first == "display3d") {
@@ -295,7 +305,7 @@ int main (int argc, char *argv[])
 	}
 #endif
 	libgoffice_init ();
-	go_plugins_init (NULL, NULL, NULL, NULL, TRUE, GO_PLUGIN_LOADER_MODULE_TYPE);
+	go_plugins_init (NULL, NULL, NULL, NULL, TRUE, GO_TYPE_PLUGIN_LOADER_MODULE);
 	in_channel = g_io_channel_unix_new (fileno (stdin));
 	g_io_add_watch (in_channel, G_IO_IN, io_func, &error);
 	gtk_main ();
