@@ -18,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -28,10 +28,12 @@
 #include "prefs.h"
 #include "window.h"
 #include <gcu/filechooser.h>
-#include <goffice/utils/go-image.h>
+#ifndef GOFFICE_HAS_GLOBAL_HEADER
+#   include <goffice/utils/go-image.h>
+#   include <gtk/gtk.h>
+#endif
 #include <gsf/gsf-output-gio.h>
 #include <glade/glade.h>
-#include <gtk/gtk.h>
 #include <cairo-pdf.h>
 #include <cairo-ps.h>
 #include <gio/gio.h>
@@ -211,7 +213,9 @@ bool gcApplication::FileProcess (const gchar* filename, const gchar* mime_type,
 		bool err = g_file_query_exists (file, NULL);
 		gint result = GTK_RESPONSE_YES;
 		if (err) {
-			gchar * message = g_strdup_printf (_("File %s\nexists, overwrite?"), filename2.c_str ());
+			char *unescaped = g_uri_unescape_string (filename2.c_str (), NULL);
+			gchar * message = g_strdup_printf (_("File %s\nexists, overwrite?"), unescaped);
+			g_free (unescaped);
 			GtkDialog* Box = GTK_DIALOG (gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, message));
 			gtk_window_set_icon_name (GTK_WINDOW (Box), "gcrystal");
 			result = gtk_dialog_run (Box);
@@ -223,7 +227,9 @@ bool gcApplication::FileProcess (const gchar* filename, const gchar* mime_type,
 					GError *error = NULL;
 					g_file_delete (file, NULL, &error);
 					if (error) {
-						gchar * message = g_strdup_printf (_("Error while processing %s:\n%s"), filename2.c_str (), error->message);
+						char *unescaped = g_uri_unescape_string (filename2.c_str (), NULL);
+						gchar * message = g_strdup_printf (_("Error while processing %s:\n%s"), unescaped, error->message);
+						g_free (unescaped);
 						g_error_free (error);
 						GtkDialog* Box = GTK_DIALOG (gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, message));
 						gtk_window_set_icon_name (GTK_WINDOW (Box), "gcrystal");
