@@ -24,11 +24,17 @@
 
 #include "config.h"
 #include "gchemtable-app.h"
-#include <goffice/goffice.h>
-#include <goffice/app/go-plugin.h>
-#include <goffice/app/go-plugin-loader-module.h>
+#ifndef GOFFICE_HAS_GLOBAL_HEADER
+#   include <goffice/goffice.h>
+#   include <goffice/app/go-plugin.h>
+#   include <goffice/app/go-plugin-loader-module.h>
+#endif
 #include <libintl.h>
 
+#ifndef GO_TYPE_PLUGIN_LOADER_MODULE
+#   define GO_TYPE_PLUGIN_LOADER_MODULE GO_PLUGIN_LOADER_MODULE_TYPE
+#endif
+
 using namespace gcu;
 
 int main (int argc, char *argv[])
@@ -36,12 +42,12 @@ int main (int argc, char *argv[])
 	textdomain (GETTEXT_PACKAGE);
 	gtk_init (&argc, &argv);
 
-	GChemTableApp *app = new GChemTableApp ();
+	new GChemTableApp ();
 	/* Initialize plugins manager */
 	GSList *l = NULL;
 	l = g_slist_append (l, (void *) "GOffice_plot_xy");
 	l = g_slist_append (l, (void *) "GOffice_reg_linear");
-	go_plugins_init (NULL, NULL, l, NULL, FALSE, GO_PLUGIN_LOADER_MODULE_TYPE);
+	go_plugins_init (NULL, NULL, l, NULL, FALSE, GO_TYPE_PLUGIN_LOADER_MODULE);
 	g_slist_free (l);
 
 	gtk_main();
